{-# LANGUAGE OverloadedStrings #-}

module Pipes.IRC.Server.Log
  ( logMsg
  , logLine
  , logOutMsg
  )
where

import           Data.ByteString.Char8  (ByteString)
import qualified Data.ByteString.Char8  as BS
import           Data.Time
import           Pipes.IRC.Message
import           Pipes.IRC.Server.Types

logMsg :: IrcMessage -> ByteString -> RegState -> IO ()
logMsg msg h userReg =
  putLog $ BS.concat ["MSG:", hStr, uStr, renderIrcMessageNoNL msg]
 where
   hStr = BS.concat [" ", h, " "]
   uStr = BS.concat $ case userReg of
     Unreg _ (Just nn) Nothing           -> [" ", nn, " ? "]
     Unreg _ Nothing   (Just name)       -> [" ? ", name, " "]
     Unreg _ (Just nn) (Just name)       -> [" ", nn," ", name, " "]
     RegUser (NickName nn (Just name) _) -> [" ", nn," ", name, " "]
     _                                   -> [" ? ? "]

logOutMsg :: IrcMessage -> [Int] -> IO ()
logOutMsg msg os =
  putLog $ BS.concat [ "OutMSG: "
                     , BS.intercalate "," $ map (BS.pack . show) os
                     , ": "
                     , renderIrcMessageNoNL msg ]

logLine :: ByteString -> IO ()
logLine = putLog

putLog :: ByteString -> IO ()
putLog l = do
  now <- getCurrentTime
  BS.putStrLn $ BS.concat [BS.pack (show now), " : ", l]
